@@ -1,6 +1,5 @@
 // -*- mode: cpp; mode: fold -*-
 // Description								/*{{{*/
-// $Id: algorithms.cc,v 1.44 2002/11/28 18:49:16 jgg Exp $
 /* ######################################################################
 
    Algorithms - A set of misc algorithms
@@ -17,31 +16,20 @@
 #include <config.h>
 
 #include <apt-pkg/algorithms.h>
-#include <apt-pkg/cachefilter.h>
 #include <apt-pkg/configuration.h>
 #include <apt-pkg/depcache.h>
 #include <apt-pkg/dpkgpm.h>
 #include <apt-pkg/edsp.h>
 #include <apt-pkg/error.h>
-#include <apt-pkg/macros.h>
 #include <apt-pkg/packagemanager.h>
 #include <apt-pkg/pkgcache.h>
-#include <apt-pkg/string_view.h>
-#include <apt-pkg/strutl.h>
-#include <apt-pkg/version.h>
-
 #include <apt-pkg/prettyprinters.h>
 
 #include <cstdlib>
 #include <iostream>
-#include <map>
-#include <set>
-#include <sstream>
 #include <string>
 #include <utility>
-#include <vector>
 #include <string.h>
-#include <sys/utsname.h>
 
 #include <apti18n.h>
 									/*}}}*/
@@ -159,7 +147,7 @@ bool pkgSimulate::RealInstall(PkgIterator iPkg,string /*File*/)
 									/*}}}*/
 // Simulate::Configure - Simulate configuration of a Package		/*{{{*/
 // ---------------------------------------------------------------------
-/* This is not an acurate simulation of relatity, we should really not
+/* This is not an accurate simulation of relatity, we should really not
    install the package.. For some investigations it may be necessary 
    however. */
 bool pkgSimulate::Configure(PkgIterator iPkg)
@@ -1355,32 +1343,6 @@ bool pkgProblemResolver::ResolveByKeepInternal()
    return true;
 }
 									/*}}}*/
-// ProblemResolver::InstallProtect - deprecated cpu-eating no-op	/*{{{*/
-// ---------------------------------------------------------------------
-/* Actions issued with FromUser bit set are protected from further
-   modification (expect by other calls with FromUser set) nowadays , so we
-   don't need to reissue actions here, they are already set in stone. */
-void pkgProblemResolver::InstallProtect()
-{
-   pkgDepCache::ActionGroup group(Cache);
-
-   for (pkgCache::PkgIterator I = Cache.PkgBegin(); I.end() == false; ++I)
-   {
-      if ((Flags[I->ID] & Protected) == Protected)
-      {
-	 if ((Flags[I->ID] & ToRemove) == ToRemove)
-	    Cache.MarkDelete(I);
-	 else 
-	 {
-	    // preserve the information whether the package was auto
-	    // or manually installed
-	    bool autoInst = (Cache[I].Flags & pkgCache::Flag::Auto);
-	    Cache.MarkInstall(I, false, 0, !autoInst);
-	 }
-      }
-   }   
-}
-									/*}}}*/
 // PrioSortList - Sort a list of versions by priority			/*{{{*/
 // ---------------------------------------------------------------------
 /* This is meant to be used in conjunction with AllTargets to get a list 
@@ -1428,171 +1390,3 @@ void pkgPrioSortList(pkgCache &Cache,pkgCache::Version **List)
    std::sort(List,List+Count,PrioComp(Cache));
 }
 									/*}}}*/
-
-namespace APT
-{
-
-namespace KernelAutoRemoveHelper
-{
-
-// \brief Returns the uname from a kernel package name, or "" for non-kernel packages.
-std::string getUname(std::string const &packageName)
-{
-
-   static const constexpr char *const prefixes[] = {
-      "linux-image-",
-      "kfreebsd-image-",
-      "gnumach-image-",
-   };
-
-   for (auto prefix : prefixes)
-   {
-      if (likely(not APT::String::Startswith(packageName, prefix)))
-	 continue;
-      if (unlikely(APT::String::Endswith(packageName, "-dbgsym")))
-	 continue;
-      if (unlikely(APT::String::Endswith(packageName, "-dbg")))
-	 continue;
-
-      auto aUname = packageName.substr(strlen(prefix));
-
-      // aUname must start with [0-9]+\.
-      if (aUname.length() < 2)
-	 continue;
-      if (strchr("0123456789", aUname[0]) == nullptr)
-	 continue;
-      auto dot = aUname.find_first_not_of("0123456789");
-      if (dot == aUname.npos || aUname[dot] != '.')
-	 continue;
-
-      return aUname;
-   }
-
-   return "";
-}
-std::string GetProtectedKernelsRegex(pkgCache *cache, bool ReturnRemove)
-{
-   if (_config->FindB("APT::Protect-Kernels", true) == false)
-      return "";
-
-   struct CompareKernel
-   {
-      pkgCache *cache;
-      bool operator()(const std::string &a, const std::string &b) const
-      {
-	 return cache->VS->CmpVersion(a, b) < 0;
-      }
-   };
-   bool Debug = _config->FindB("Debug::pkgAutoRemove", false);
-   // kernel version -> list of unames
-   std::map<std::string, std::vector<std::string>, CompareKernel> version2unames(CompareKernel{cache});
-   // needs to be initialized to 0s, might not be set up.
-   utsname uts{};
-   std::string bootedVersion;
-
-   // Get currently booted version, but only when not on reproducible build.
-   if (getenv("SOURCE_DATE_EPOCH") == 0)
-   {
-      if (uname(&uts) != 0)
-	 abort();
-   }
-
-   auto VirtualKernelPkg = cache->FindPkg(APT::StringView("$kernel"), "any");
-   if (VirtualKernelPkg.end())
-      return "";
-
-   for (pkgCache::PrvIterator Prv = VirtualKernelPkg.ProvidesList(); Prv.end() == false; ++Prv)
-   {
-      auto Pkg = Prv.OwnerPkg();
-      if (likely(Pkg->CurrentVer == 0))
-	 continue;
-
-      auto pkgUname = APT::KernelAutoRemoveHelper::getUname(Pkg.Name());
-      auto pkgVersion = Pkg.CurrentVer().VerStr();
-
-      if (pkgUname.empty())
-	 continue;
-
-      if (Debug)
-	 std::clog << "Found kernel " << pkgUname << "(" << pkgVersion << ")" << std::endl;
-
-      version2unames[pkgVersion].push_back(pkgUname);
-
-      if (pkgUname == uts.release)
-	 bootedVersion = pkgVersion;
-   }
-
-   if (version2unames.size() == 0)
-      return "";
-
-   auto latest = version2unames.rbegin();
-   auto previous = latest;
-   ++previous;
-
-   std::set<std::string> keep;
-
-   if (not bootedVersion.empty())
-   {
-      if (Debug)
-	 std::clog << "Keeping booted kernel " << bootedVersion << std::endl;
-      keep.insert(bootedVersion);
-   }
-   if (latest != version2unames.rend())
-   {
-      if (Debug)
-	 std::clog << "Keeping latest kernel " << latest->first << std::endl;
-      keep.insert(latest->first);
-   }
-   if (keep.size() < 2 && previous != version2unames.rend())
-   {
-      if (Debug)
-	 std::clog << "Keeping previous kernel " << previous->first << std::endl;
-      keep.insert(previous->first);
-   }
-   // Escape special characters '.' and '+' in version strings so we can build a regular expression
-   auto escapeSpecial = [](std::string input) -> std::string {
-      for (size_t pos = 0; (pos = input.find_first_of(".+", pos)) != input.npos; pos += 2) {
-	 input.insert(pos, 1, '\\');
-      }
-      return input;
-   };
-   std::ostringstream ss;
-   for (auto &pattern : _config->FindVector("APT::VersionedKernelPackages"))
-   {
-      // Legacy compatibility: Always protected the booted uname and last installed uname
-      if (*uts.release)
-	 ss << "|^" << pattern << "-" << escapeSpecial(uts.release) << "$";
-      for (auto const &kernel : version2unames)
-      {
-	 if (ReturnRemove ? keep.find(kernel.first) == keep.end() : keep.find(kernel.first) != keep.end())
-	 {
-	    for (auto const &uname : kernel.second)
-	       ss << "|^" << pattern << "-" << escapeSpecial(uname) << "$";
-	 }
-      }
-   }
-
-   auto re_with_leading_or = ss.str();
-
-   if (re_with_leading_or.empty())
-      return "";
-
-   auto re = re_with_leading_or.substr(1);
-   if (Debug)
-      std::clog << "Kernel protection regex: " << re << "\n";
-
-   return re;
-}
-
-std::unique_ptr<APT::CacheFilter::Matcher> GetProtectedKernelsFilter(pkgCache *cache, bool returnRemove)
-{
-   auto regex = GetProtectedKernelsRegex(cache, returnRemove);
-
-   if (regex.empty())
-      return std::unique_ptr<APT::CacheFilter::FalseMatcher>(new APT::CacheFilter::FalseMatcher());
-
-   return std::unique_ptr<APT::CacheFilter::PackageNameMatchesRegEx>(new APT::CacheFilter::PackageNameMatchesRegEx(regex));
-}
-
-} // namespace KernelAutoRemoveHelper
-} // namespace APT
