@@ -8,10 +8,6 @@
 
 #include <stddef.h>
 
-#ifndef APT_8_CLEANER_HEADERS
-#include <apt-pkg/init.h>
-using namespace std;
-#endif
 
 class Configuration;
 class OpProgress;
