@@ -26,15 +26,6 @@
 
 #include "hashsum_template.h"
 
-#ifndef APT_10_CLEANER_HEADERS
-#include <algorithm>
-#include <cstring>
-#include <string>
-#endif
-#ifndef APT_8_CLEANER_HEADERS
-using std::string;
-using std::min;
-#endif
 
 typedef HashSumValue<128> MD5SumValue;
 
