@@ -28,8 +28,5 @@ namespace APT {
    }
 }
 
-APT_DEPRECATED_MSG("Use APT::Upgrade::Upgrade() instead") bool pkgDistUpgrade(pkgDepCache &Cache);
-APT_DEPRECATED_MSG("Use APT::Upgrade::Upgrade() instead") bool pkgAllUpgrade(pkgDepCache &Cache);
-
 bool pkgMinimizeUpgrade(pkgDepCache &Cache);
 #endif
