@@ -39,17 +39,26 @@ struct PackageSortAlphabetic						/*{{{*/
 
 class PackageNameMatcher : public Matcher
 {
+   pkgCacheFile &cacheFile;
   public:
-   explicit PackageNameMatcher(const char **patterns)
+   explicit PackageNameMatcher(pkgCacheFile &cacheFile, const char **patterns)
+   : cacheFile(cacheFile)
    {
       for(int i=0; patterns[i] != NULL; ++i)
       {
          std::string pattern = patterns[i];
-         APT::CacheFilter::PackageMatcher *cachefilter = NULL;
-         if(_config->FindB("APT::Cmd::Use-Regexp", false) == true)
+         APT::CacheFilter::Matcher *cachefilter = NULL;
+         if (pattern.size() > 0 && pattern[0] == '?')
+            cachefilter = APT::CacheFilter::ParsePattern(pattern, &cacheFile).release();
+         else if(_config->FindB("APT::Cmd::Use-Regexp", false) == true)
             cachefilter = new APT::CacheFilter::PackageNameMatchesRegEx(pattern);
          else
             cachefilter = new APT::CacheFilter::PackageNameMatchesFnmatch(pattern);
+
+         if (cachefilter == nullptr) {
+            return;
+            filters.clear();
+         }
          filters.push_back(cachefilter);
       }
    }
@@ -62,7 +71,7 @@ class PackageNameMatcher : public Matcher
    {
       for(J=filters.begin(); J != filters.end(); ++J)
       {
-         APT::CacheFilter::PackageMatcher *cachefilter = *J;
+         APT::CacheFilter::Matcher *cachefilter = *J;
          if((*cachefilter)(P)) 
             return true;
       }
@@ -70,8 +79,8 @@ class PackageNameMatcher : public Matcher
    }
 
 private:
-   std::vector<APT::CacheFilter::PackageMatcher*> filters;   
-   std::vector<APT::CacheFilter::PackageMatcher*>::const_iterator J;
+   std::vector<APT::CacheFilter::Matcher*> filters;
+   std::vector<APT::CacheFilter::Matcher*>::const_iterator J;
    #undef PackageMatcher
 };
 									/*}}}*/
@@ -111,7 +120,7 @@ bool DoList(CommandLine &Cmd)
    if (_config->FindB("APT::Cmd::List-Include-Summary", false) == true)
       format += "\n  ${Description}\n";
 
-   PackageNameMatcher matcher(patterns);
+   PackageNameMatcher matcher(CacheFile, patterns);
    LocalitySortedVersionSet bag;
    OpTextProgress progress(*_config);
    progress.OverallProgress(0,
