@@ -148,8 +148,7 @@ static bool DoDSelectUpgrade(CommandLine &)
    pkgDepCache::ActionGroup group(Cache);
 
    // Install everything with the install flag set
-   pkgCache::PkgIterator I = Cache->PkgBegin();
-   for (;I.end() != true; ++I)
+   for (pkgCache::PkgIterator I = Cache->PkgBegin(); I.end() != true; ++I)
    {
       /* Install the package only if it is a new install, the autoupgrader
          will deal with the rest */
@@ -159,7 +158,7 @@ static bool DoDSelectUpgrade(CommandLine &)
 
    /* Now install their deps too, if we do this above then order of
       the status file is significant for | groups */
-   for (I = Cache->PkgBegin();I.end() != true; ++I)
+   for (pkgCache::PkgIterator I = Cache->PkgBegin(); I.end() != true; ++I)
    {
       /* Install the package only if it is a new install, the autoupgrader
          will deal with the rest */
@@ -168,7 +167,7 @@ static bool DoDSelectUpgrade(CommandLine &)
    }
    
    // Apply erasures now, they override everything else.
-   for (I = Cache->PkgBegin();I.end() != true; ++I)
+   for (pkgCache::PkgIterator I = Cache->PkgBegin(); I.end() != true; ++I)
    {
       // Remove packages 
       if (I->SelectedState == pkgCache::State::DeInstall ||
